@@ -357,7 +357,7 @@ function onUpdateProgress()
   var base = 0;
   var dls = gDownloadManager.activeDownloads;
   while (dls.hasMoreElements()) {
-    let dl = dls.getNext().QueryInterface(Ci.nsIDownload);
+    let dl = dls.getNext();
     if (dl.percentComplete < 100 && dl.size > 0) {
       mean += dl.amountTransferred;
       base += dl.size;
@@ -1101,7 +1101,6 @@ function buildDownloadList(aForceBuild)
   gBuilder = setTimeout(function() {
     // Start building the list and select the first item
     stepListBuilder(1);
-    gDownloadsView.selectedIndex = 0;
 
     // We just tried to add a single item, so we probably need to enable
     updateClearListButton();
